==> hydropandas-0.7.2.tar.gz: hydropandas-0.7.2/tests/test_007_wiski.py <==
# -*- coding: utf-8 -*-
"""Created on Mon Jun 24 11:43:27 2019.

@author: oebbe
"""

import hydropandas as hpd
from hydropandas.io import wiski


def test_read_wiski_csv():
    # download single file

    wiski.read_wiski_file(
        "./tests/data/2019-WISKI-test/1016_PBF.csv",
        sep=r"\s+",
        header_sep=":",
        header_identifier=":",
        verbose=True,
        parse_dates={"datetime": [0, 1]},
        infer_datetime_format=True,
        index_col=["datetime"],
        translate_dic={"name": "Station Number", "x": "GlobalX", "y": "GlobalY"},
    )

    return


def test_read_wiski_csv2():
    # download single file

    wiski.read_wiski_file(
        "./tests/data/2019-WISKI-test/8137_PBF.csv",
        sep=r"\s+",
        header_sep=":",
        header_identifier=":",
        verbose=True,
        parse_dates={"datetime": [0, 1]},
        infer_datetime_format=False,
        dayfirst=True,
        index_col=["datetime"],
        translate_dic={"name": "Station Number", "x": "GlobalX", "y": "GlobalY"},
    )

    return


def test_read_wiski_zip():
    wiski.read_wiski_dir(
        "./tests/data/2019-WISKI-test/1016_PBF.zip",
        ObsClass=hpd.GroundwaterObs,
        sep=r"\s+",
        header_sep=":",
        header_identifier=":",
        parse_dates={"datetime": [0, 1]},
        index_col=["datetime"],
        translate_dic={"name": "Station Number", "x": "GlobalX", "y": "GlobalY"},
        verbose=True,
    )

    return


def test_rijnenijssel_wiski_format():
    hpd.GroundwaterObs.from_wiski(
        (
            "./tests/data/2019-WISKI-test/"
            "Zwiepse Horstweg Barchem_1024_FT1_WNS9040_MomentaanO.csv"
        ),
        header_sep=";",
        end_header_str="#Timestamp",
        parse_dates=[0],
        index_col=[0],
        infer_datetime_format=True,
        tz_localize=False,
    )
    return

==> hydropandas-0.16.0.tar.gz: hydropandas-0.16.0/tests/test_007_wiski.py <==
from pathlib import Path

import hydropandas as hpd
from hydropandas.io import wiski

wiski_data_path = Path(__file__).parent / "data/2019-WISKI-test"


def test_read_wiski_csv() -> None:
    # download single file

    wiski.read_wiski_file(
        wiski_data_path / "1016_PBF.csv",
        sep=r"\s+",
        header_sep=":",
        header_identifier=":",
        verbose=True,
        parse_dates={"datetime": [0, 1]},
        dayfirst=True,
        index_col=["datetime"],
        translate_dic={"name": "Station Number", "x": "GlobalX", "y": "GlobalY"},
    )


def test_read_wiski_csv2() -> None:
    # download single file

    wiski.read_wiski_file(
        wiski_data_path / "8137_PBF.csv",
        sep=r"\s+",
        header_sep=":",
        header_identifier=":",
        verbose=True,
        parse_dates={"datetime": [0, 1]},
        dayfirst=True,
        index_col=["datetime"],
        translate_dic={"name": "Station Number", "x": "GlobalX", "y": "GlobalY"},
    )


def test_read_wiski_zip() -> None:
    wiski.read_wiski_dir(
        str(wiski_data_path / "1016_PBF.zip"),
        ObsClass=hpd.GroundwaterObs,
        sep=r"\s+",
        header_sep=":",
        header_identifier=":",
        parse_dates={"datetime": [0, 1]},
        index_col=["datetime"],
        translate_dic={"name": "Station Number", "x": "GlobalX", "y": "GlobalY"},
        dayfirst=True,
    )


def test_rijnenijssel_wiski_format() -> None:
    hpd.GroundwaterObs.from_wiski(
        wiski_data_path / "Zwiepse Horstweg Barchem_1024_FT1_WNS9040_MomentaanO.csv",
        header_sep=";",
        end_header_str="#Timestamp",
        parse_dates=[0],
        index_col=[0],
        tz_localize=False,
    )
